@@ -1,4 +1,3 @@
-#### $Id: misc-goodies.R,v 1.48 2014/06/15 15:26:37 maechler Exp $
 #### misc-goodies.R
 #### ~~~~~~~~~~~~~~  SfS - R - goodies that are NOT in
 ####		"/u/sfs/R/SfS/R/u.goodies.R"
@@ -975,7 +974,7 @@ unif <- function(n, round.dig = 1 + trunc(log10(n)))
   }
 }
 
-globalVariables("DEBUG")
+if(getRversion() >= "2.15.1") globalVariables("DEBUG")
 prt.DEBUG <- function(..., LEVEL = 1) {
   warning("prt.DEBUG() is deprecated: use a 'verbose' argument or options(verbose=.) instead")
   if (exists("DEBUG", where = 1) && DEBUG >= LEVEL )#
