@@ -1,6 +1,5 @@
-#### PostScript Goodies fr R --- `a la /u/sfs/S/ps.goodies.S
+#### PostScript Goodies f r R --- `a la /u/sfs/S/ps.goodies.S
 ####
-#### $Id: ps.goodies.R,v 1.21 2014/04/23 18:01:57 maechler Exp $
 ####
 
 ## hidden in the name space -- FIXME? maybe more useful ?? ---
@@ -266,4 +265,4 @@ pdf.end <- function(call.viewer = NULL, command = getOption("pdfviewer"),
 ## Alain Hauser <alain@huschhus.ch> --> ../man/cairoSwd.Rd
 cairoSwd <- function(name, width, height, ...)
   cairo_pdf(filename = paste(name, "pdf", sep = "."),
-            width = width, height = height, ...)
+            width = width, height = height)
